package PureMessage::Enduser::Config::Validator;
use base qw(PureMessage::Config::Validator Exporter);
use PureMessage::Config qw(%config);

sub validate {
    my ($pkg, $p) = @_;
    $p->typedecl('access_log', '#str');
    $p->typedecl('audit_log', '#str');
    $p->typedecl('error_log', '#str');
    $p->typedecl('enduser_url','#str');
    $p->typedecl('auth','#str');
    $p->typedecl('allow.users','#str');
    $p->typedecl('allow.hosts','#str'); # todo validate that they are lists and that they exist
    $p->typedecl('allow.reasons','#list #str'); 
    $p->typedecl('limit.vacation_expiry','#duration');
    $p->typedecl('limit.query_wait','#duration');
    $p->typedecl('enabled','#bool');
    $p->typedecl('unavailable_banner','#str');
    $p->typedecl('limit.max_list_items','#int');
    $p->typedecl('Authenticator#*.description','#str');
    $p->typedecl('Authenticator#*.module','#str');
    $p->typedecl('Authenticator#*.config.*','#any');
    $p->typedecl('Authenticator#email_session.config.session_expire','#duration');
    $p->typedecl('session.driver','#str');
    $p->typedecl('session.args.session_expire','#duration');
    $p->typedecl('session.args.expire.*','#duration');
    $p->typedecl('session.args.*','#any');
    $p->typedecl('lists.whitelist','#any');
    $p->typedecl('lists.blacklist','#any');
    $p->typedecl('quarantine_expiry_days','#num');
    $p->typedecl('gmt_offset','#duration');
    $p->typedecl('user_store','#str');
    $p->typedecl('max_view_messages','#int');
    $p->typedecl('features','#str');
    $p->typedecl('recipient_aliases_map_location','#str'); 
    
    $p->default('features','local');
    $p->default('access_log', 'enduser/rpc_access.log');
    $p->default('allow.users', 'enduser-users');
    $p->default('allow.hosts', 'enduser-rpc-hosts');
    $p->default('allow.reasons',['spam']); 
    $p->default('audit_log', 'enduser/rpc_audit.log');
    $p->default('error_log', 'enduser/rpc_error.log');
    $p->default('limit.vacation_expiry','7d');
    $p->default('limit.query_wait','1m');
    $p->default('session.driver','driver:File');
    $p->default('session.args.session_expire','12h');
    $p->default('Authenticator#email_session.config.session_expire','1w');
    $p->default('lists.whitelist','whitelisted-senders-per-user');
    $p->default('lists.blacklist','blacklisted-senders-per-user');
    $p->default('enabled','yes');
    $p->default('unavailable_banner','Temporarily Unavailable.');
    $p->default('quarantine_expiry_days',get_qexpire_days());
    $p->default('gmt_offset','0s');
    $p->default('user_store','dir:enduser_user_store');
    $p->default('limit.max_list_items',20);
    $p->default('max_view_messages',0); # by default disabled
    $p->default('recipient_aliases_map_location', 'database'); 
    
    my @enduser_features = ('quarantine.messages',
			    'quarantine.body',
			    'list.white',
			    'list.black',
			    'list.wildcard',
			    'option.spam_optout',
			    'option.digest_optout',
			    'option.vacation',
			    'email.notification',
			    'language.preference',
			);
    foreach my $ef (@enduser_features) {
	$p->typedecl("feature.$ef", '#bool');
    }
  
}

sub get_qexpire_days {
    my $retention_days = ($config{quarantine_expire}->{expire_time})/(24*60*60);
    return $retention_days if $retention_days;
    return -1;
}

1;
